@@ -36,12 +36,21 @@ Options:
   -a|--assert <function ...args>
     Run a core assert function standalone without a test context.
 
+  --debug
+    Print all executed shell commands to the terminal.
+
   -e|--env <file-path>
     Load a custom env file overriding the .env environment variables.
 
   -f|--filter <filter>
     Filters the tests to run based on the test name.
 
+  -l|--log-junit <out.xml>
+    Create a report JUnit XML file that contains information about the test results.
+
+  -r|--report-html <out.html>
+    Create a report HTML file that contains information about the test results.
+
   -s|simple || -v|verbose
     Enables simplified or verbose output to the console.
 
