@@ -1,6 +1,5 @@
 #!/bin/bash
 
-_START_TIME=$(date +%s%N);
 _SUCCESSFUL_TEST_COUNT=0
 
 function console_results::render_result() {
@@ -9,24 +8,24 @@ function console_results::render_result() {
     printf "%s%s%s\n" "${_COLOR_RETURN_ERROR}" "Duplicate test functions found" "${_COLOR_DEFAULT}"
     printf "File with duplicate functions: %s\n" "$(state::get_file_with_duplicated_function_names)"
     printf "Duplicate functions: %s\n" "$(state::get_duplicated_function_names)"
-    exit 1
+    return 1
   fi
 
   echo ""
 
   local total_tests=0
-  ((total_tests+=$(state::get_tests_passed)))
-  ((total_tests+=$(state::get_tests_skipped)))
-  ((total_tests+=$(state::get_tests_incomplete)))
-  ((total_tests+=$(state::get_tests_snapshot)))
-  ((total_tests+=$(state::get_tests_failed)))
+  ((total_tests += $(state::get_tests_passed))) || true
+  ((total_tests += $(state::get_tests_skipped))) || true
+  ((total_tests += $(state::get_tests_incomplete))) || true
+  ((total_tests += $(state::get_tests_snapshot))) || true
+  ((total_tests += $(state::get_tests_failed))) || true
 
   local total_assertions=0
-  ((total_assertions+=$(state::get_assertions_passed)))
-  ((total_assertions+=$(state::get_assertions_skipped)))
-  ((total_assertions+=$(state::get_assertions_incomplete)))
-  ((total_assertions+=$(state::get_assertions_snapshot)))
-  ((total_assertions+=$(state::get_assertions_failed)))
+  ((total_assertions += $(state::get_assertions_passed))) || true
+  ((total_assertions += $(state::get_assertions_skipped))) || true
+  ((total_assertions += $(state::get_assertions_incomplete))) || true
+  ((total_assertions += $(state::get_assertions_snapshot))) || true
+  ((total_assertions += $(state::get_assertions_failed))) || true
 
   printf "%sTests:     %s" "$_COLOR_FAINT" "$_COLOR_DEFAULT"
   if [[ "$(state::get_tests_passed)" -gt 0 ]] || [[ "$(state::get_assertions_passed)" -gt 0 ]]; then
@@ -67,36 +66,36 @@ function console_results::render_result() {
   if [[ "$(state::get_tests_failed)" -gt 0 ]]; then
     printf "\n%s%s%s\n" "$_COLOR_RETURN_ERROR" " Some tests failed " "$_COLOR_DEFAULT"
     console_results::print_execution_time
-    exit 1
+    return 1
   fi
 
   if [[ "$(state::get_tests_incomplete)" -gt 0 ]]; then
     printf "\n%s%s%s\n" "$_COLOR_RETURN_INCOMPLETE" " Some tests incomplete " "$_COLOR_DEFAULT"
     console_results::print_execution_time
-    exit 0
+    return 0
   fi
 
   if [[ "$(state::get_tests_skipped)" -gt 0 ]]; then
     printf "\n%s%s%s\n" "$_COLOR_RETURN_SKIPPED" " Some tests skipped " "$_COLOR_DEFAULT"
     console_results::print_execution_time
-    exit 0
+    return 0
   fi
 
   if [[ "$(state::get_tests_snapshot)" -gt 0 ]]; then
     printf "\n%s%s%s\n" "$_COLOR_RETURN_SNAPSHOT" " Some snapshots created " "$_COLOR_DEFAULT"
     console_results::print_execution_time
-    exit 0
+    return 0
   fi
 
   if [[ $total_tests -eq 0 ]]; then
     printf "\n%s%s%s\n" "$_COLOR_RETURN_ERROR" " No tests found " "$_COLOR_DEFAULT"
     console_results::print_execution_time
-    exit 1
+    return 1
   fi
 
   printf "\n%s%s%s\n" "$_COLOR_RETURN_SUCCESS" " All tests passed " "$_COLOR_DEFAULT"
   console_results::print_execution_time
-  exit 0
+  return 0
 }
 
 function console_results::print_execution_time() {
@@ -104,14 +103,12 @@ function console_results::print_execution_time() {
     return
   fi
 
-  if [[ "$_OS" != "OSX" ]]; then
-    _EXECUTION_TIME=$((($(date +%s%N) - "$_START_TIME") / 1000000))
-    printf "${_COLOR_BOLD}%s${_COLOR_DEFAULT}\n" "Time taken: ${_EXECUTION_TIME} ms"
-  fi
+  _EXECUTION_TIME=$(clock::runtime_in_milliseconds)
+  printf "${_COLOR_BOLD}%s${_COLOR_DEFAULT}\n" "Time taken: ${_EXECUTION_TIME} ms"
 }
 
 function console_results::print_successful_test() {
-  ((_SUCCESSFUL_TEST_COUNT++))
+  ((_SUCCESSFUL_TEST_COUNT++)) || true
 
   if [[ "$SIMPLE_OUTPUT" == true ]]; then
     if (( _SUCCESSFUL_TEST_COUNT % 50 != 0 )); then
@@ -146,8 +143,8 @@ function console_results::print_failed_test() {
   local expected=$2
   local failure_condition_message=$3
   local actual=$4
-  local extra_key=$5
-  local extra_value=$6
+  local extra_key=${5-}
+  local extra_value=${6-}
 
   printf "\
 ${_COLOR_FAILED}✗ Failed${_COLOR_DEFAULT}: %s
@@ -181,7 +178,7 @@ function console_results::print_failed_snapshot_test() {
 
 function console_results::print_skipped_test() {
   local test_name=$1
-  local reason=$2
+  local reason=${2-}
 
   printf "${_COLOR_SKIPPED}↷ Skipped${_COLOR_DEFAULT}: %s\n" "${test_name}"
 
@@ -192,7 +189,7 @@ function console_results::print_skipped_test() {
 
 function console_results::print_incomplete_test() {
   local test_name=$1
-  local pending=$2
+  local pending=${2-}
 
   printf "${_COLOR_INCOMPLETE}✒ Incomplete${_COLOR_DEFAULT}: %s\n" "${test_name}"
 
