@@ -48,7 +48,7 @@ function runner::functions_for_script() {
 
 # Helper function for test authors to invoke a named test case
 function run_test() {
-  runner::run_test "$function_name" "$@"
+  runner::run_test "testing-fn" "$function_name" "$@"
 }
 
 function runner::call_test_functions() {
@@ -71,7 +71,7 @@ function runner::call_test_functions() {
       echo "Running $script"
     fi
 
-    helper::check_duplicate_functions "$script"
+    helper::check_duplicate_functions "$script" || true
 
     for function_name in "${functions_to_run[@]}"; do
       local provider_data=()
@@ -79,7 +79,7 @@ function runner::call_test_functions() {
 
       if [[ "${#provider_data[@]}" -gt 0 ]]; then
         for data in "${provider_data[@]}"; do
-          runner::run_test "$function_name" "$data"
+          runner::run_test "$script" "$function_name" "$data"
         done
       else
         local multi_invoker
@@ -87,7 +87,7 @@ function runner::call_test_functions() {
         if [[ -n "${multi_invoker}" ]]; then
           helper::execute_function_if_exists "${multi_invoker}"
         else
-          runner::run_test "$function_name"
+          runner::run_test "$script" "$function_name"
         fi
       fi
 
@@ -134,14 +134,19 @@ function runner::parse_execution_result() {
     sed -E -e 's/.*##ASSERTIONS_SNAPSHOT=([0-9]*)##.*/\1/g'\
   )
 
-  _ASSERTIONS_PASSED=$((_ASSERTIONS_PASSED + assertions_passed))
-  _ASSERTIONS_FAILED=$((_ASSERTIONS_FAILED + assertions_failed))
-  _ASSERTIONS_SKIPPED=$((_ASSERTIONS_SKIPPED + assertions_skipped))
-  _ASSERTIONS_INCOMPLETE=$((_ASSERTIONS_INCOMPLETE + assertions_incomplete))
-  _ASSERTIONS_SNAPSHOT=$((_ASSERTIONS_SNAPSHOT + assertions_snapshot))
+  ((_ASSERTIONS_PASSED += assertions_passed)) || true
+  ((_ASSERTIONS_FAILED += assertions_failed)) || true
+  ((_ASSERTIONS_SKIPPED += assertions_skipped)) || true
+  ((_ASSERTIONS_INCOMPLETE += assertions_incomplete)) || true
+  ((_ASSERTIONS_SNAPSHOT += assertions_snapshot)) || true
 }
 
 function runner::run_test() {
+  local start_time
+  start_time=$(clock::now)
+
+  local test_file="$1"
+  shift
   local function_name="$1"
   shift
   local current_assertions_failed
@@ -181,18 +186,20 @@ function runner::run_test() {
   local runtime_error
   runtime_error=$(\
     echo "$test_execution_result" |\
-    head -n 1 |\
+    tail -n 1 |\
     sed -E -e 's/(.*)##ASSERTIONS_FAILED=.*/\1/g'\
   )
 
   if [[ -n $runtime_error ]]; then
     state::add_tests_failed
     console_results::print_error_test "$function_name" "$runtime_error"
+    logger::test_failed "$test_file" "$function_name" "$start_time"
     return
   fi
 
   if [[ "$current_assertions_failed" != "$(state::get_assertions_failed)" ]]; then
     state::add_tests_failed
+    logger::test_failed "$test_file" "$function_name" "$start_time"
 
     if [ "$STOP_ON_FAILURE" = true ]; then
       exit 1
@@ -204,16 +211,19 @@ function runner::run_test() {
   if [[ "$current_assertions_snapshot" != "$(state::get_assertions_snapshot)" ]]; then
     state::add_tests_snapshot
     console_results::print_snapshot_test "$function_name"
+    logger::test_snapshot "$test_file" "$function_name" "$start_time"
     return
   fi
 
   if [[ "$current_assertions_incomplete" != "$(state::get_assertions_incomplete)" ]]; then
     state::add_tests_incomplete
+    logger::test_incomplete "$test_file" "$function_name" "$start_time"
     return
   fi
 
   if [[ "$current_assertions_skipped" != "$(state::get_assertions_skipped)" ]]; then
     state::add_tests_skipped
+    logger::test_skipped "$test_file" "$function_name" "$start_time"
     return
   fi
 
@@ -222,6 +232,7 @@ function runner::run_test() {
 
   console_results::print_successful_test "${label}" "$@"
   state::add_tests_passed
+  logger::test_passed "$test_file" "$function_name" "$start_time"
 }
 
 function runner::run_set_up() {
