@@ -1,7 +1,7 @@
 #!/bin/bash
 
 function skip() {
-  local reason=$1
+  local reason=${1-}
   local label
   label="$(helper::normalize_test_function_name "${FUNCNAME[1]}")"
 
@@ -11,7 +11,7 @@ function skip() {
 }
 
 function todo() {
-  local pending=$1
+  local pending=${1-}
   local label
   label="$(helper::normalize_test_function_name "${FUNCNAME[1]}")"
 
